import request from '@/router/axios'


// 导出汇总报告
export function taskExportNbqybg(query) {
  return request({
    url: '/admin/wmtask/exportNba',
    method: 'get',
    params: query
  })
}

export function taskExportExcelNbqybg(query) {
  return request({
    url: '/admin/report/excel/export/exportNba',
    method: 'get',
    params: query
  })
}

export function taskNewExport(query) {
  return request({
    url: '/admin/reportExport/new-nba-export',
    method: 'get',
    params: query
  })
}

export function taskNewExcel(query) {
  return request({
    url: '/admin/reportExport/new-excel-export',
    method: 'get',
    params: query
  })
}

export function taskAssignPointsWord(query) {
  return request({
    url: '/admin/reportExport/exportZbReport',
    method: 'get',
    params: query
  })
}

export function taskAssignPointsExcel(query) {
  return request({
    url: '/admin/report/excel/export/exportZbReport',
    method: 'get',
    params: query
  })
}


export function taskAssignPointsNewWord(query) {
  return request({
    url: '/admin/reportExport/new-personal-export',
    method: 'get',
    params: query
  })
}
